==> cxf-testutils-2.0.6.14-fuse-sources.jar: org/apache/type_test/doc/TestExtBase64Binary.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types2.ExtBase64Binary;


/**
 * <p>Java class for testExtBase64Binary element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testExtBase64Binary">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types2}ExtBase64Binary"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types2}ExtBase64Binary"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testExtBase64Binary")
public class TestExtBase64Binary {

    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected ExtBase64Binary x;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected ExtBase64Binary y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link ExtBase64Binary }
     *     
     */
    public ExtBase64Binary getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtBase64Binary }
     *     
     */
    public void setX(ExtBase64Binary value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link ExtBase64Binary }
     *     
     */
    public ExtBase64Binary getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtBase64Binary }
     *     
     */
    public void setY(ExtBase64Binary value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.18-fuse-sources.jar: org/apache/type_test/doc/TestExtBase64Binary.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types2.ExtBase64Binary;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types2}ExtBase64Binary"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types2}ExtBase64Binary"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testExtBase64Binary")
public class TestExtBase64Binary {

    @XmlElement(required = true)
    protected ExtBase64Binary x;
    @XmlElement(required = true)
    protected ExtBase64Binary y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link ExtBase64Binary }
     *     
     */
    public ExtBase64Binary getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtBase64Binary }
     *     
     */
    public void setX(ExtBase64Binary value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link ExtBase64Binary }
     *     
     */
    public ExtBase64Binary getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtBase64Binary }
     *     
     */
    public void setY(ExtBase64Binary value) {
        this.y = value;
    }

}
